Module: Couchdb
- Defined in:
- lib/leanback.rb
Class Attribute Summary collapse
-
.address ⇒ Object
Returns the value of attribute address.
-
.port ⇒ Object
Returns the value of attribute port.
Class Method Summary collapse
-
.add_counter(options, auth_session = "") ⇒ Object
add a counter method to the database this creates a count method that counts documents by key.
-
.add_finder(options, auth_session = "") ⇒ Object
add a finder method to the database this creates a find by key method.
-
.add_multiple_counter(options, auth_session = "") ⇒ Object
add a multiple counter method to the database this creates a count by keys method.
-
.add_multiple_finder(options, auth_session = "") ⇒ Object
add a multiple finder method to the database this creates a find by keys method.
-
.add_user(user, auth_session = "") ⇒ Object
add a new user.
-
.all(auth_session = "") ⇒ Object
return a list of all databases.
-
.change_password(username, new_password, auth_session = "") ⇒ Object
change non-admin user password.
- .couch_error(e) ⇒ Object
-
.count(options, auth_session = "") ⇒ Object
count by key.
-
.count_by_keys(options, auth_session = "", params = {}) ⇒ Object
count by keys example: hash = {:firstname =>‘john’, :gender => ‘male’ } Couchdb.count_by_keys(=> ‘contacts’, :keys => hash,auth_session).
-
.create(database_name, auth_session = "") ⇒ Object
create a database if one with the same name doesn’t already exist.
-
.create_design(doc, auth_session = "") ⇒ Object
create a design document with views.
-
.create_doc(doc, auth_session = "") ⇒ Object
create a document.
-
.create_user(user, auth_session = "") ⇒ Object
create a new user.
-
.delete(database_name, auth_session = "") ⇒ Object
delete a database.
- .delete_config(data, auth_session = "") ⇒ Object
-
.delete_doc(doc, auth_session = "") ⇒ Object
delete document.
-
.delete_rev(doc, auth_session = "") ⇒ Object
delete a doc by rev#.
-
.docs_from(database_name, auth_session = "") ⇒ Object
return a list of all docs in the database.
-
.edit_doc(doc, auth_session = "") ⇒ Object
edit a document.
-
.find(doc, auth_session = "", key = nil, options = {}) ⇒ Object
query a permanent view.
-
.find_by(options, auth_session = "", params = {}) ⇒ Object
find by key.
-
.find_by_keys(options, auth_session = "", params = {}) ⇒ Object
find by keys example: hash = {:firstname =>‘john’, :gender => ‘male’ } Couchdb.find_by_keys(=> ‘contacts’, :keys => hash,auth_session).
-
.find_on_fly(doc, auth_session = "", key = nil, options = {}) ⇒ Object
Query view, create view on fly if it dosen’t already exist.
- .get_config(data, auth_session = "") ⇒ Object
- .get_params(options) ⇒ Object
-
.get_security(db_name, auth_session = "") ⇒ Object
get security object.
-
.login(username, password) ⇒ Object
login to couchdb.
- .salt ⇒ Object
- .set_address ⇒ Object
-
.set_config(data, auth_session = "") ⇒ Object
couchdb configuration api.
-
.set_security(db_name, data, auth_session = "") ⇒ Object
add security object.
-
.update_doc(doc, auth_session = "") ⇒ Object
update a doc.
-
.view(doc, auth_session = "", options = {}) ⇒ Object
view a document.
Class Attribute Details
.address ⇒ Object
Returns the value of attribute address.
602 603 604 |
# File 'lib/leanback.rb', line 602 def address @address end |
.port ⇒ Object
Returns the value of attribute port.
603 604 605 |
# File 'lib/leanback.rb', line 603 def port @port end |
Class Method Details
.add_counter(options, auth_session = "") ⇒ Object
add a counter method to the database this creates a count method that counts documents by key
444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/leanback.rb', line 444 def self.add_counter(,auth_session = "") set_address db_name = [:database] key = [:key] design_doc_name = key + '_counter' view ='{ "language" : "javascript", "views" :{ "count_'+key+'" : { "map" : "function(doc){ if(doc.'+key+') emit(doc.'+key+',null);}", "reduce": "_count" } } }' begin response = RestClient.put "#{@address}:#{@port}/#{db_name}/_design/#{design_doc_name}", view, {:cookies => {"AuthSession" => auth_session}} rescue => e couch_error(e) end end |
.add_finder(options, auth_session = "") ⇒ Object
add a finder method to the database this creates a find by key method
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/leanback.rb', line 367 def self.add_finder(,auth_session = "") set_address db_name = [:database] key = [:key] design_doc_name = key + '_finder' view ='{ "language" : "javascript", "views" :{ "find_by_'+key+'" : { "map" : "function(doc){ if(doc.'+key+') emit(doc.'+key+',doc);}" } } }' begin response = RestClient.put "#{@address}:#{@port}/#{db_name}/_design/#{design_doc_name}", view, {:cookies => {"AuthSession" => auth_session}} rescue => e couch_error(e) end end |
.add_multiple_counter(options, auth_session = "") ⇒ Object
add a multiple counter method to the database this creates a count by keys method
418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/leanback.rb', line 418 def self.add_multiple_counter(,auth_session = "") set_address db_name = [:database] keys = [:keys] view_name = keys.join("_") key = keys.join(",doc.") condition = keys.join(" && doc.") design_doc_name = "#{view_name}_keys_counter" view = '{ "language" : "javascript", "views" :{ "count_by_keys_'+view_name+'" : { "map" : "function(doc){ if(doc.'+condition+') emit([doc.'+key+'],null);}", "reduce": "_count" } } }' begin response = RestClient.put "#{@address}:#{@port}/#{db_name}/_design/#{design_doc_name}", view, {:cookies => {"AuthSession" => auth_session}} rescue => e couch_error(e) end end |
.add_multiple_finder(options, auth_session = "") ⇒ Object
add a multiple finder method to the database this creates a find by keys method
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/leanback.rb', line 391 def self.add_multiple_finder(,auth_session = "") set_address db_name = [:database] keys = [:keys] view_name = keys.join("_") key = keys.join(",doc.") condition = keys.join(" && doc.") design_doc_name = "#{view_name}_keys_finder" view = '{ "language" : "javascript", "views" :{ "find_by_keys_'+view_name+'" : { "map" : "function(doc){ if(doc.'+condition+') emit([doc.'+key+'],doc);}" } } }' begin response = RestClient.put "#{@address}:#{@port}/#{db_name}/_design/#{design_doc_name}", view, {:cookies => {"AuthSession" => auth_session}} rescue => e couch_error(e) end end |
.add_user(user, auth_session = "") ⇒ Object
add a new user
35 36 37 38 39 40 |
# File 'lib/leanback.rb', line 35 def self.add_user(user, auth_session="") o = [('a'..'z'),('A'..'Z')].map{|i| i.to_a}.flatten; salt = (0..50).map{ o[rand(o.length)] }.join; new_user = {:username => user[:username], :password => user[:password], :roles => user[:roles], :salt => salt} create_user(new_user,auth_session) end |
.all(auth_session = "") ⇒ Object
return a list of all databases
230 231 232 233 234 235 236 237 238 |
# File 'lib/leanback.rb', line 230 def self.all(auth_session = "") set_address begin response = RestClient.get "#{@address}:#{@port}/_all_dbs", {:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e raise e end end |
.change_password(username, new_password, auth_session = "") ⇒ Object
change non-admin user password
25 26 27 28 29 30 31 32 |
# File 'lib/leanback.rb', line 25 def self.change_password(username, new_password,auth_session = "") salty = salt() password_sha = Digest::SHA1.hexdigest(new_password + salty) user_id = 'org.couchdb.user:' + username data = {"salt" => salty,"password_sha" => password_sha} doc = { :database => '_users', :doc_id => user_id, :data => data} update_doc doc,auth_session end |
.couch_error(e) ⇒ Object
13 14 15 16 17 |
# File 'lib/leanback.rb', line 13 def self.couch_error(e) raise e if e.is_a? OpenSSL::SSL::SSLError hash = Yajl::Parser.parse(e.response.to_s) raise CouchdbException.new(hash), "CouchDB: Error - #{hash.values[0]}. Reason - #{hash.values[1]}" end |
.count(options, auth_session = "") ⇒ Object
count by key
467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 |
# File 'lib/leanback.rb', line 467 def self.count(,auth_session = "") set_address db_name = [:database] index = .keys[1].to_s search_term = .values[1] design_doc_name = "#{index}_counter" view_name = "count_#{index}" begin view = { :database => db_name, :design_doc => design_doc_name, :view => view_name} docs = find view,auth_session,search_term rescue CouchdbException => e #add a counter index if one doesn't already exist in the database #then count_by_key add_counter({:database => db_name, :key => index},auth_session) docs = find view,auth_session,search_term end count = docs[0] return count.to_i end |
.count_by_keys(options, auth_session = "", params = {}) ⇒ Object
count by keys example: hash = {:firstname =>‘john’, :gender => ‘male’ } Couchdb.count_by_keys(=> ‘contacts’, :keys => hash,auth_session)
492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 |
# File 'lib/leanback.rb', line 492 def self.count_by_keys(,auth_session = "", params = {}) set_address db_name = [:database] keys = [] search_term = [] hash = [:keys] hash.each do |k,v| keys << k search_term << v end index = keys.join("_") design_doc_name = "#{index}_keys_counter" view_name = "count_by_keys_#{index}" params[:startkey] = search_term params[:endkey] = search_term begin view = { :database => db_name, :design_doc => design_doc_name, :view => view_name} docs = find view,auth_session,key=nil,params rescue CouchdbException => e #add a finder/index if one doesn't already exist in the database #then find_by_keys add_multiple_counter({:database => db_name, :keys => keys},auth_session) docs = find view,auth_session,key=nil,params end count = docs[0] return count.to_i end |
.create(database_name, auth_session = "") ⇒ Object
create a database if one with the same name doesn’t already exist
208 209 210 211 212 213 214 215 216 |
# File 'lib/leanback.rb', line 208 def self.create(database_name,auth_session = "") set_address begin response = RestClient.put "#{@address}:#{@port}/#{URI.escape(database_name)}", {:content_type => :json},{:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e couch_error(e) end end |
.create_design(doc, auth_session = "") ⇒ Object
create a design document with views
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/leanback.rb', line 317 def self.create_design(doc,auth_session = "") set_address db_name = doc[:database] design_doc_name = doc[:design_doc] json_doc_name = doc[:json_doc] begin #bind json doc to string = ERB.new File.new(json_doc_name).read str = .result(binding) rescue => e raise e end begin response = RestClient.put "#{@address}:#{@port}/#{db_name}/_design/#{design_doc_name}", str, {:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e couch_error(e) end end |
.create_doc(doc, auth_session = "") ⇒ Object
create a document
140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/leanback.rb', line 140 def self.create_doc( doc,auth_session = "") db_name = doc[:database] doc_id = doc[:doc_id] data = doc[:data] json_data = Yajl::Encoder.encode(data) set_address begin response = RestClient.put "#{@address}:#{@port}/#{URI.escape(db_name)}/#{URI.escape(doc_id)}",json_data, {:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e couch_error(e) end end |
.create_user(user, auth_session = "") ⇒ Object
create a new user
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/leanback.rb', line 43 def self.create_user(user,auth_session= "") password_sha = Digest::SHA1.hexdigest(user[:password] + user[:salt]) user_hash = { :type => "user", :name => user[:username], :password_sha => password_sha, :salt => user[:salt], :roles => user[:roles] } str = Yajl::Encoder.encode(user_hash) set_address begin response = RestClient.put "#{@address}:#{@port}/_users/org.couchdb.user:#{URI.escape(user[:username])}", str,{:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e couch_error(e) end end |
.delete(database_name, auth_session = "") ⇒ Object
delete a database
219 220 221 222 223 224 225 226 227 |
# File 'lib/leanback.rb', line 219 def self.delete(database_name,auth_session = "") set_address begin response = RestClient.delete "#{@address}:#{@port}/#{URI.escape(database_name)}", {:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e couch_error(e) end end |
.delete_config(data, auth_session = "") ⇒ Object
114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/leanback.rb', line 114 def self.delete_config(data,auth_session = "") section = data[:section] key = data[:key] set_address begin response = RestClient.delete "#{@address}:#{@port}/_config/#{URI.escape(section)}/#{URI.escape(key)}", {:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e couch_error(e) end end |
.delete_doc(doc, auth_session = "") ⇒ Object
delete document
182 183 184 185 186 187 188 189 |
# File 'lib/leanback.rb', line 182 def self.delete_doc(doc,auth_session = "") db_name = doc[:database] doc_id = doc[:doc_id] doc = {:database => db_name, :doc_id => doc_id} hash = Couchdb.view doc,auth_session doc = {:database => db_name, :doc_id => doc_id, :rev => hash["_rev"]} delete_rev(doc,auth_session) end |
.delete_rev(doc, auth_session = "") ⇒ Object
delete a doc by rev#
193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/leanback.rb', line 193 def self.delete_rev(doc,auth_session = "") db_name = doc[:database] doc_id = doc[:doc_id] rev = doc[:rev] set_address begin response = RestClient.delete "#{@address}:#{@port}/#{URI.escape(db_name)}/#{URI.escape(doc_id)}?rev=#{rev}", {:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e couch_error(e) end end |
.docs_from(database_name, auth_session = "") ⇒ Object
return a list of all docs in the database
577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 |
# File 'lib/leanback.rb', line 577 def self.docs_from(database_name,auth_session = "") set_address begin response = RestClient.get "#{@address}:#{@port}/#{URI.escape(database_name)}/_all_docs?include_docs=true",{:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rows = hash["rows"] count = 0 rows.each do |row| rows[count] = row["doc"] count += 1 end return rows rescue => e couch_error(e) end end |
.edit_doc(doc, auth_session = "") ⇒ Object
edit a document
155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/leanback.rb', line 155 def self.edit_doc(doc,auth_session = "") db_name = doc[:database] doc_id = doc[:doc_id] data = doc[:data] json_data = Yajl::Encoder.encode(data) set_address begin response = RestClient.put "#{@address}:#{@port}/#{URI.escape(db_name)}/#{URI.escape(doc_id)}", json_data, {:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e couch_error(e) end end |
.find(doc, auth_session = "", key = nil, options = {}) ⇒ Object
query a permanent view
287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/leanback.rb', line 287 def self.find(doc,auth_session = "", key=nil, = {}) set_address db_name = doc[:database] design_doc_name = doc[:design_doc] view_name = doc[:view] params = get_params() begin if key == nil response = RestClient.get "#{@address}:#{@port}/#{db_name}/_design/#{design_doc_name}/_view/#{view_name}?#{URI.escape(params)}",{:cookies => {"AuthSession" => auth_session}} else key = URI.escape('?key="' + key + '"') response = RestClient.get "#{@address}:#{@port}/#{db_name}/_design/#{design_doc_name}/_view/#{view_name}#{key}&#{URI.escape(params)}" ,{:cookies => {"AuthSession" => auth_session}} end hash = Yajl::Parser.parse(response.to_str, symbolize_keys()) data = [] rows = hash["rows"] unless hash["rows"].nil? rows = hash[:rows] unless hash[:rows].nil? rows.each do |row| value = row["value"] unless row["value"].nil? value = row[:value] unless row[:value].nil? data << value end return data rescue => e couch_error(e) end end |
.find_by(options, auth_session = "", params = {}) ⇒ Object
find by key
523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 |
# File 'lib/leanback.rb', line 523 def self.find_by(,auth_session = "", params = {}) set_address db_name = [:database] index = .keys[1].to_s search_term = .values[1] design_doc_name = "#{index}_finder" view_name = "find_by_#{index}" begin view = { :database => db_name, :design_doc => design_doc_name, :view => view_name} docs = find view,auth_session,search_term,params rescue CouchdbException => e #add a finder/index if one doesn't already exist in the database #then find_by_key add_finder({:database => db_name, :key => index},auth_session) docs = find view,auth_session,search_term,params end return docs end |
.find_by_keys(options, auth_session = "", params = {}) ⇒ Object
find by keys example: hash = {:firstname =>‘john’, :gender => ‘male’ } Couchdb.find_by_keys(=> ‘contacts’, :keys => hash,auth_session)
547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 |
# File 'lib/leanback.rb', line 547 def self.find_by_keys(,auth_session = "", params = {}) set_address db_name = [:database] keys = [] search_term = [] hash = [:keys] hash.each do |k,v| keys << k search_term << v end index = keys.join("_") design_doc_name = "#{index}_keys_finder" view_name = "find_by_keys_#{index}" params[:startkey] = search_term params[:endkey] = search_term begin view = { :database => db_name, :design_doc => design_doc_name, :view => view_name} docs = find view,auth_session,key=nil,params rescue CouchdbException => e #add a finder/index if one doesn't already exist in the database #then find_by_keys add_multiple_finder({:database => db_name, :keys => keys},auth_session) docs = find view,auth_session,key=nil,params end return docs end |
.find_on_fly(doc, auth_session = "", key = nil, options = {}) ⇒ Object
Query view, create view on fly if it dosen’t already exist
340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/leanback.rb', line 340 def self.find_on_fly(doc,auth_session = "",key = nil, = {}) db_name = doc[:database] design_doc = doc[:design_doc] view = doc[:view] json_doc = doc[:json_doc] query_info = {:database => db_name, :design_doc => design_doc, :view => view} begin if( key == nil) docs = find(query_info,auth_session,key=nil,) else docs = find(query_info,auth_session,key,) end rescue CouchdbException => e document = { :database => db_name, :design_doc => design_doc, :json_doc => json_doc} create_design document,auth_session if( key == nil) docs = find(query_info,auth_session,key=nil,) else docs = find(query_info,auth_session,key,) end end return docs end |
.get_config(data, auth_session = "") ⇒ Object
127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/leanback.rb', line 127 def self.get_config(data,auth_session = "") section = data[:section] key = data[:key] set_address begin response = RestClient.get "#{@address}:#{@port}/_config/#{URI.escape(section)}/#{URI.escape(key)}", {:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e couch_error(e) end end |
.get_params(options) ⇒ Object
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/leanback.rb', line 253 def self.get_params() params = "" if .has_key?(:startkey) if [:startkey].is_a? String params = 'startkey="' + [:startkey] + '"' else params = 'startkey=' + [:startkey].to_s # for complex keys end end if .has_key?(:endkey) if [:endkey].is_a? String params = params + '&endkey="' + [:endkey] + '"' else params = params + '&endkey=' + [:endkey].to_s #for complex keys end end if .has_key?(:limit) params = params + "&" + "limit=" + [:limit].to_s end if .has_key?(:skip) params = params + "&" + "skip=" + [:skip].to_s end if .has_key?(:descending) params = params + "&" + "descending=true" end return params end |
.get_security(db_name, auth_session = "") ⇒ Object
get security object
77 78 79 80 81 82 83 84 85 |
# File 'lib/leanback.rb', line 77 def self.get_security(db_name, auth_session="") set_address begin response = RestClient.get "#{@address}:#{@port}/#{URI.escape(db_name)}/_security/", {:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e couch_error(e) end end |
.login(username, password) ⇒ Object
login to couchdb
88 89 90 91 92 93 94 95 96 97 |
# File 'lib/leanback.rb', line 88 def self.login(username, password) set_address data = "name=#{username}&password=#{password}" begin response = RestClient.post "#{@address}:#{@port}/_session/", data, {:content_type => 'application/x-www-form-urlencoded'} response. rescue => e couch_error(e) end end |
.salt ⇒ Object
19 20 21 22 |
# File 'lib/leanback.rb', line 19 def self.salt o = [('a'..'z'),('A'..'Z')].map{|i| i.to_a}.flatten; salt = (0..50).map{ o[rand(o.length)] }.join; end |
.set_address ⇒ Object
605 606 607 608 609 610 611 612 |
# File 'lib/leanback.rb', line 605 def set_address() if @address == nil @address = 'http://127.0.0.1' end if @port == nil @port = '5984' end end |
.set_config(data, auth_session = "") ⇒ Object
couchdb configuration api
100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/leanback.rb', line 100 def self.set_config(data,auth_session = "") section = data[:section] key = data[:key] value = data[:value] json_data = Yajl::Encoder.encode(value) set_address begin response = RestClient.put "#{@address}:#{@port}/_config/#{URI.escape(section)}/#{URI.escape(key)}",json_data, {:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e couch_error(e) end end |
.set_security(db_name, data, auth_session = "") ⇒ Object
add security object
65 66 67 68 69 70 71 72 73 74 |
# File 'lib/leanback.rb', line 65 def self.set_security(db_name, data,auth_session="") security_data = Yajl::Encoder.encode(data) set_address begin response = RestClient.put "#{@address}:#{@port}/#{URI.escape(db_name)}/_security/",security_data, {:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str) rescue => e couch_error(e) end end |
.update_doc(doc, auth_session = "") ⇒ Object
update a doc
170 171 172 173 174 175 176 177 178 179 |
# File 'lib/leanback.rb', line 170 def self.update_doc(doc,auth_session = "") db_name = doc[:database] doc_id = doc[:doc_id] data = doc[:data] doc = {:database => db_name, :doc_id => doc_id} = Couchdb.view doc,auth_session = .merge(data) doc = {:database => db_name, :doc_id => doc_id, :data => } edit_doc doc,auth_session end |
.view(doc, auth_session = "", options = {}) ⇒ Object
view a document
241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/leanback.rb', line 241 def self.view(doc,auth_session = "", = {}) set_address db_name = doc[:database] doc_id = doc[:doc_id] begin response = RestClient.get "#{@address}:#{@port}/#{db_name}/#{doc_id}",{:cookies => {"AuthSession" => auth_session}} hash = Yajl::Parser.parse(response.to_str, symbolize_keys()) rescue => e couch_error(e) end end |